@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,6 +16,7 @@
  */
 package org.apache.commons.lang3;
 
+import static org.apache.commons.lang3.LangAssertions.assertIllegalArgumentException;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -47,19 +48,17 @@ import org.junit.jupiter.api.DisplayName;
 import org.junit.jupiter.api.Test;
 
 /**
- * Unit tests {@link org.apache.commons.lang3.ClassUtils}.
+ * Tests {@link ClassUtils}.
  */
 @SuppressWarnings("boxing") // JUnit4 does not support primitive equality testing apart from long
-public class ClassUtilsTest extends AbstractLangTest {
-
-    private static final String OBJECT_CANONICAL_NAME = "java.lang.Object";
+class ClassUtilsTest extends AbstractLangTest {
 
     private static class CX implements IB, IA, IE {
         // empty
     }
 
     @SuppressWarnings("unused") // IB is redundant but what a test checks
-    private static class CY extends CX implements IB, IC {
+    private static final class CY extends CX implements IB, IC {
         // empty
     }
 
@@ -87,12 +86,14 @@ public class ClassUtilsTest extends AbstractLangTest {
         // empty
     }
 
-    private static class Inner {
-        private class DeeplyNested {
+    private static final class Inner {
+        private static final class DeeplyNested {
             // empty
         }
     }
 
+    private static final String OBJECT_CANONICAL_NAME = "java.lang.Object";
+
     private void assertGetClassReturnsClass(final Class<?> c) throws Exception {
         assertEquals(c, ClassUtils.getClass(c.getName()));
     }
@@ -111,7 +112,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_convertClassesToClassNames_List() {
+    void test_convertClassesToClassNames_List() {
         final List<Class<?>> list = new ArrayList<>();
         List<String> result = ClassUtils.convertClassesToClassNames(list);
         assertEquals(0, result.size());
@@ -133,7 +134,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_convertClassNamesToClasses_List() {
+    void test_convertClassNamesToClasses_List() {
         final List<String> list = new ArrayList<>();
         List<Class<?>> result = ClassUtils.convertClassNamesToClasses(list);
         assertEquals(0, result.size());
@@ -155,7 +156,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getAbbreviatedName_Class() {
+    void test_getAbbreviatedName_Class() {
         assertEquals("", ClassUtils.getAbbreviatedName((Class<?>) null, 1));
         assertEquals("j.l.String", ClassUtils.getAbbreviatedName(String.class, 1));
         assertEquals("j.l.String", ClassUtils.getAbbreviatedName(String.class, 5));
@@ -167,18 +168,18 @@ public class ClassUtilsTest extends AbstractLangTest {
 
     @Test
     @DisplayName("When the desired length is negative then exception is thrown")
-    public void test_getAbbreviatedName_Class_NegativeLen() {
-        assertThrows(IllegalArgumentException.class, () -> ClassUtils.getAbbreviatedName(String.class, -10));
+    void test_getAbbreviatedName_Class_NegativeLen() {
+        assertIllegalArgumentException(() -> ClassUtils.getAbbreviatedName(String.class, -10));
     }
 
     @Test
     @DisplayName("When the desired length is zero then exception is thrown")
-    public void test_getAbbreviatedName_Class_ZeroLen() {
-        assertThrows(IllegalArgumentException.class, () -> ClassUtils.getAbbreviatedName(String.class, 0));
+    void test_getAbbreviatedName_Class_ZeroLen() {
+        assertIllegalArgumentException(() -> ClassUtils.getAbbreviatedName(String.class, 0));
     }
 
     @Test
-    public void test_getAbbreviatedName_String() {
+    void test_getAbbreviatedName_String() {
         assertEquals("", ClassUtils.getAbbreviatedName((String) null, 1));
         assertEquals("", ClassUtils.getAbbreviatedName("", 1));
         assertEquals("WithoutPackage", ClassUtils.getAbbreviatedName("WithoutPackage", 1));
@@ -207,14 +208,14 @@ public class ClassUtilsTest extends AbstractLangTest {
      */
     @Test
     @DisplayName("When the length hint is longer than the actual length then the same String object is returned")
-    public void test_getAbbreviatedName_TooLongHint() {
+    void test_getAbbreviatedName_TooLongHint() {
         final String className = "java.lang.String";
         Assertions.assertSame(className, ClassUtils.getAbbreviatedName(className, className.length() + 1));
         Assertions.assertSame(className, ClassUtils.getAbbreviatedName(className, className.length()));
     }
 
     @Test
-    public void test_getAllInterfaces_Class() {
+    void test_getAllInterfaces_Class() {
         final List<?> list = ClassUtils.getAllInterfaces(CY.class);
         assertEquals(6, list.size());
         assertEquals(IB.class, list.get(0));
@@ -228,7 +229,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getAllSuperclasses_Class() {
+    void test_getAllSuperclasses_Class() {
         final List<?> list = ClassUtils.getAllSuperclasses(CY.class);
         assertEquals(2, list.size());
         assertEquals(CX.class, list.get(0));
@@ -238,7 +239,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getCanonicalName_Class() {
+    void test_getCanonicalName_Class() {
         assertEquals("org.apache.commons.lang3.ClassUtils", ClassUtils.getCanonicalName(ClassUtils.class));
         assertEquals("java.util.Map.Entry", ClassUtils.getCanonicalName(Map.Entry.class));
         assertEquals("", ClassUtils.getCanonicalName((Class<?>) null));
@@ -272,7 +273,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("java.lang.String[][][][]", ClassUtils.getCanonicalName(String[][][][].class));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals(StringUtils.EMPTY, ClassUtils.getCanonicalName(new Object() {
@@ -283,7 +284,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getCanonicalName_Class_String() {
+    void test_getCanonicalName_Class_String() {
         assertEquals("org.apache.commons.lang3.ClassUtils", ClassUtils.getCanonicalName(ClassUtils.class, "X"));
         assertEquals("java.util.Map.Entry", ClassUtils.getCanonicalName(Map.Entry.class, "X"));
         assertEquals("X", ClassUtils.getCanonicalName((Class<?>) null, "X"));
@@ -317,7 +318,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("java.lang.String[][][][]", ClassUtils.getCanonicalName(String[][][][].class, "X"));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("X", ClassUtils.getCanonicalName(new Object() {
@@ -330,12 +331,12 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getClass() {
+    void test_getClass() {
        // assertEquals("org.apache.commons.lang3.ClassUtils", ClassUtils.getName(ClassLoader.class, "@"));
     }
 
     @Test
-    public void test_getName_Class() {
+    void test_getName_Class() {
         assertEquals("org.apache.commons.lang3.ClassUtils", ClassUtils.getName(ClassUtils.class));
         assertEquals("java.util.Map$Entry", ClassUtils.getName(Map.Entry.class));
         assertEquals("", ClassUtils.getName((Class<?>) null));
@@ -369,7 +370,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("[[[[Ljava.lang.String;", ClassUtils.getName(String[][][][].class));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("org.apache.commons.lang3.ClassUtilsTest$3", ClassUtils.getName(new Object() {
@@ -381,14 +382,14 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getName_Object() {
+    void test_getName_Object() {
         assertEquals("org.apache.commons.lang3.ClassUtils", ClassUtils.getName(new ClassUtils(), "<null>"));
         assertEquals("org.apache.commons.lang3.ClassUtilsTest$Inner", ClassUtils.getName(new Inner(), "<null>"));
         assertEquals("java.lang.String", ClassUtils.getName("hello", "<null>"));
         assertEquals("<null>", ClassUtils.getName(null, "<null>"));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("org.apache.commons.lang3.ClassUtilsTest$4", ClassUtils.getName(new Object() {
@@ -399,7 +400,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getPackageCanonicalName_Class() {
+    void test_getPackageCanonicalName_Class() {
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils.class));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils[].class));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils[][].class));
@@ -407,7 +408,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("", ClassUtils.getPackageCanonicalName(int[][].class));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new Object() {
@@ -419,7 +420,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getPackageCanonicalName_Object() {
+    void test_getPackageCanonicalName_Object() {
         assertEquals("<null>", ClassUtils.getPackageCanonicalName(null, "<null>"));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new ClassUtils(), "<null>"));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new ClassUtils[0], "<null>"));
@@ -428,7 +429,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("", ClassUtils.getPackageCanonicalName(new int[0][0], "<null>"));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new Object() {
@@ -439,7 +440,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getPackageCanonicalName_String() {
+    void test_getPackageCanonicalName_String() {
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName("org.apache.commons.lang3.ClassUtils"));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName("[Lorg.apache.commons.lang3.ClassUtils;"));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName("[[Lorg.apache.commons.lang3.ClassUtils;"));
@@ -457,7 +458,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getPackageName_Class() {
+    void test_getPackageName_Class() {
         assertEquals("java.lang", ClassUtils.getPackageName(String.class));
         assertEquals("java.util", ClassUtils.getPackageName(Map.Entry.class));
         assertEquals("", ClassUtils.getPackageName((Class<?>) null));
@@ -481,7 +482,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("java.lang", ClassUtils.getPackageName(String[][][][].class));
 
         // On-the-fly types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(new Object() {
@@ -491,14 +492,14 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getPackageName_Object() {
+    void test_getPackageName_Object() {
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(new ClassUtils(), "<null>"));
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(new Inner(), "<null>"));
         assertEquals("<null>", ClassUtils.getPackageName(null, "<null>"));
     }
 
     @Test
-    public void test_getPackageName_String() {
+    void test_getPackageName_String() {
         assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(ClassUtils.class.getName()));
         assertEquals("java.util", ClassUtils.getPackageName(Map.Entry.class.getName()));
         assertEquals("", ClassUtils.getPackageName((String) null));
@@ -506,7 +507,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getShortCanonicalName_Class() {
+    void test_getShortCanonicalName_Class() {
         assertEquals("ClassUtils", ClassUtils.getShortCanonicalName(ClassUtils.class));
         assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName(ClassUtils[].class));
         assertEquals("ClassUtils[][]", ClassUtils.getShortCanonicalName(ClassUtils[][].class));
@@ -514,7 +515,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("int[][]", ClassUtils.getShortCanonicalName(int[][].class));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("", ClassUtils.getShortCanonicalName(new Object() {
@@ -527,7 +528,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getShortCanonicalName_Object() {
+    void test_getShortCanonicalName_Object() {
         assertEquals("<null>", ClassUtils.getShortCanonicalName(null, "<null>"));
         assertEquals("ClassUtils", ClassUtils.getShortCanonicalName(new ClassUtils(), "<null>"));
         assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName(new ClassUtils[0], "<null>"));
@@ -536,7 +537,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("int[][]", ClassUtils.getShortCanonicalName(new int[0][0], "<null>"));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("", ClassUtils.getShortCanonicalName(new Object() {
@@ -547,7 +548,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getShortCanonicalName_String() {
+    void test_getShortCanonicalName_String() {
         assertEquals("", ClassUtils.getShortCanonicalName((String) null));
         assertEquals("Map.Entry", ClassUtils.getShortCanonicalName(java.util.Map.Entry.class.getName()));
         assertEquals("Entry", ClassUtils.getShortCanonicalName(java.util.Map.Entry.class.getCanonicalName()));
@@ -562,13 +563,13 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("int[][]", ClassUtils.getShortCanonicalName("[[I"));
         assertEquals("int[]", ClassUtils.getShortCanonicalName("int[]"));
         assertEquals("int[][]", ClassUtils.getShortCanonicalName("int[][]"));
-
         // this is to demonstrate that the documentation and the naming of the methods
         // uses the class name and canonical name totally mixed up, which cannot be
         // fixed without backward compatibility break
         assertEquals("int[]", int[].class.getCanonicalName());
         assertEquals("[I", int[].class.getName());
-
+        assertIllegalArgumentException(() -> ClassUtils.getShortCanonicalName(StringUtils.repeat("[", 256) + "I"));
+        assertEquals("int" + StringUtils.repeat("[]", 255), ClassUtils.getShortCanonicalName(StringUtils.repeat("[", 255) + "I"));
         // Inner types... the problem is that these are not canonical names, classes with this name do not even have canonical
         // name
         // WARNING: this is fragile, implementation may change, naming is not guaranteed
@@ -581,10 +582,22 @@ public class ClassUtilsTest extends AbstractLangTest {
         }.getClass().getName());
         assertNull(new org.apache.commons.lang3.ClassUtilsTest() {
         }.getClass().getCanonicalName());
+        assertEquals("String[]", ClassUtils.getShortCanonicalName(String[].class.getName()));
+        assertEquals("String[]", ClassUtils.getShortCanonicalName(String[].class.getCanonicalName()));
+        assertEquals("String[]", ClassUtils.getShortCanonicalName("String[]"));
+        // Note that we throw RuntimeException (but not which one) for the following bad inputs:
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName(""));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("["));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("[]"));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("[;"));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("[];"));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName(" "));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("[$"));
+        assertThrows(RuntimeException.class, () -> ClassUtils.getShortCanonicalName("[$a"));
     }
 
     @Test
-    public void test_getShortClassName_Class() {
+    void test_getShortClassName_Class() {
         assertEquals("ClassUtils", ClassUtils.getShortClassName(ClassUtils.class));
         assertEquals("Map.Entry", ClassUtils.getShortClassName(Map.Entry.class));
         assertEquals("", ClassUtils.getShortClassName((Class<?>) null));
@@ -619,7 +632,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("String[][][][]", ClassUtils.getShortClassName(String[][][][].class));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         // WARNING: this is fragile, implementation may change, naming is not guaranteed
@@ -632,14 +645,14 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getShortClassName_Object() {
+    void test_getShortClassName_Object() {
         assertEquals("ClassUtils", ClassUtils.getShortClassName(new ClassUtils(), "<null>"));
         assertEquals("ClassUtilsTest.Inner", ClassUtils.getShortClassName(new Inner(), "<null>"));
         assertEquals("String", ClassUtils.getShortClassName("hello", "<null>"));
         assertEquals("<null>", ClassUtils.getShortClassName(null, "<null>"));
 
         // Inner types
-        class Named {
+        final class Named {
             // empty
         }
         // WARNING: this is fragile, implementation may change, naming is not guaranteed
@@ -652,7 +665,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getShortClassName_String() {
+    void test_getShortClassName_String() {
         assertEquals("ClassUtils", ClassUtils.getShortClassName(ClassUtils.class.getName()));
         assertEquals("Map.Entry", ClassUtils.getShortClassName(Map.Entry.class.getName()));
         assertEquals("", ClassUtils.getShortClassName((String) null));
@@ -660,7 +673,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getSimpleName_Class() {
+    void test_getSimpleName_Class() {
         assertEquals("ClassUtils", ClassUtils.getSimpleName(ClassUtils.class));
         assertEquals("Entry", ClassUtils.getSimpleName(Map.Entry.class));
         assertEquals("", ClassUtils.getSimpleName(null));
@@ -695,7 +708,7 @@ public class ClassUtilsTest extends AbstractLangTest {
         assertEquals("String[][][][]", ClassUtils.getSimpleName(String[][][][].class));
 
         // On-the-fly types
-        class Named {
+        final class Named {
             // empty
         }
         assertEquals("", ClassUtils.getSimpleName(new Object() {
@@ -705,7 +718,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getSimpleName_Object() {
+    void test_getSimpleName_Object() {
         assertEquals("ClassUtils", ClassUtils.getSimpleName(new ClassUtils()));
         assertEquals("Inner", ClassUtils.getSimpleName(new Inner()));
         assertEquals("String", ClassUtils.getSimpleName("hello"));
@@ -714,7 +727,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_getSimpleName_Object_String() {
+    void test_getSimpleName_Object_String() {
         assertEquals("ClassUtils", ClassUtils.getSimpleName(new ClassUtils(), "<null>"));
         assertEquals("Inner", ClassUtils.getSimpleName(new Inner(), "<null>"));
         assertEquals("String", ClassUtils.getSimpleName("hello", "<null>"));
@@ -723,7 +736,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable() {
+    void test_isAssignable() {
         assertFalse(ClassUtils.isAssignable((Class<?>) null, null));
         assertFalse(ClassUtils.isAssignable(String.class, null));
 
@@ -749,7 +762,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_Autoboxing() {
+    void test_isAssignable_Autoboxing() {
         assertFalse(ClassUtils.isAssignable((Class<?>) null, null, true));
         assertFalse(ClassUtils.isAssignable(String.class, null, true));
 
@@ -773,7 +786,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_ClassArray_ClassArray() {
+    void test_isAssignable_ClassArray_ClassArray() {
         final Class<?>[] array2 = new Class[] {Object.class, Object.class};
         final Class<?>[] array1 = new Class[] {Object.class};
         final Class<?>[] array1s = new Class[] {String.class};
@@ -801,7 +814,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_ClassArray_ClassArray_Autoboxing() {
+    void test_isAssignable_ClassArray_ClassArray_Autoboxing() {
         final Class<?>[] array2 = new Class[] {Object.class, Object.class};
         final Class<?>[] array1 = new Class[] {Object.class};
         final Class<?>[] array1s = new Class[] {String.class};
@@ -829,7 +842,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_ClassArray_ClassArray_NoAutoboxing() {
+    void test_isAssignable_ClassArray_ClassArray_NoAutoboxing() {
         final Class<?>[] array2 = new Class[] {Object.class, Object.class};
         final Class<?>[] array1 = new Class[] {Object.class};
         final Class<?>[] array1s = new Class[] {String.class};
@@ -857,7 +870,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_DefaultUnboxing_Widening() {
+    void test_isAssignable_DefaultUnboxing_Widening() {
         // test byte conversions
         assertFalse(ClassUtils.isAssignable(Byte.class, Character.TYPE), "byte -> char");
         assertTrue(ClassUtils.isAssignable(Byte.class, Byte.TYPE), "byte -> byte");
@@ -940,7 +953,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_NoAutoboxing() {
+    void test_isAssignable_NoAutoboxing() {
         assertFalse(ClassUtils.isAssignable((Class<?>) null, null, false));
         assertFalse(ClassUtils.isAssignable(String.class, null, false));
 
@@ -964,7 +977,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_Unboxing_Widening() {
+    void test_isAssignable_Unboxing_Widening() {
         // test byte conversions
         assertFalse(ClassUtils.isAssignable(Byte.class, Character.TYPE, true), "byte -> char");
         assertTrue(ClassUtils.isAssignable(Byte.class, Byte.TYPE, true), "byte -> byte");
@@ -1047,7 +1060,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isAssignable_Widening() {
+    void test_isAssignable_Widening() {
         // test byte conversions
         assertFalse(ClassUtils.isAssignable(Byte.TYPE, Character.TYPE), "byte -> char");
         assertTrue(ClassUtils.isAssignable(Byte.TYPE, Byte.TYPE), "byte -> byte");
@@ -1130,7 +1143,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void test_isInnerClass_Class() {
+    void test_isInnerClass_Class() {
         assertTrue(ClassUtils.isInnerClass(Inner.class));
         assertTrue(ClassUtils.isInnerClass(Map.Entry.class));
         assertTrue(ClassUtils.isInnerClass(new Cloneable() {
@@ -1142,7 +1155,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testComparable() {
+    void testComparable() {
         final TreeMap<Class<?>, String> map = new TreeMap<>(ClassUtils.comparator());
         map.put(String.class, "lastEntry");
         map.toString();
@@ -1160,7 +1173,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testConstructor() {
+    void testConstructor() {
         assertNotNull(new ClassUtils());
         final Constructor<?>[] cons = ClassUtils.class.getDeclaredConstructors();
         assertEquals(1, cons.length);
@@ -1170,7 +1183,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassByNormalNameArrays() throws ClassNotFoundException {
+    void testGetClassByNormalNameArrays() throws ClassNotFoundException {
         assertEquals(int[].class, ClassUtils.getClass("int[]"));
         assertEquals(long[].class, ClassUtils.getClass("long[]"));
         assertEquals(short[].class, ClassUtils.getClass("short[]"));
@@ -1187,7 +1200,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassByNormalNameArrays2D() throws ClassNotFoundException {
+    void testGetClassByNormalNameArrays2D() throws ClassNotFoundException {
         assertEquals(int[][].class, ClassUtils.getClass("int[][]"));
         assertEquals(long[][].class, ClassUtils.getClass("long[][]"));
         assertEquals(short[][].class, ClassUtils.getClass("short[][]"));
@@ -1200,14 +1213,14 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassClassNotFound() throws Exception {
+    void testGetClassClassNotFound() throws Exception {
         assertGetClassThrowsClassNotFound("bool");
         assertGetClassThrowsClassNotFound("bool[]");
         assertGetClassThrowsClassNotFound("integer[]");
     }
 
     @Test
-    public void testGetClassInvalidArguments() throws Exception {
+    void testGetClassInvalidArguments() throws Exception {
         assertGetClassThrowsNullPointerException(null);
         assertGetClassThrowsClassNotFound("[][][]");
         assertGetClassThrowsClassNotFound("[[]");
@@ -1218,7 +1231,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassRawPrimitives() throws ClassNotFoundException {
+    void testGetClassRawPrimitives() throws ClassNotFoundException {
         assertEquals(int.class, ClassUtils.getClass("int"));
         assertEquals(long.class, ClassUtils.getClass("long"));
         assertEquals(short.class, ClassUtils.getClass("short"));
@@ -1231,7 +1244,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassWithArrayClasses() throws Exception {
+    void testGetClassWithArrayClasses() throws Exception {
         assertGetClassReturnsClass(String[].class);
         assertGetClassReturnsClass(int[].class);
         assertGetClassReturnsClass(long[].class);
@@ -1244,7 +1257,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClassWithArrayClasses2D() throws Exception {
+    void testGetClassWithArrayClasses2D() throws Exception {
         assertGetClassReturnsClass(String[][].class);
         assertGetClassReturnsClass(int[][].class);
         assertGetClassReturnsClass(long[][].class);
@@ -1257,7 +1270,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetComponentType() {
+    void testGetComponentType() {
         final CX[] newArray = {};
         @SuppressWarnings("unchecked")
         final Class<CX[]> classCxArray = (Class<CX[]>) newArray.getClass();
@@ -1268,7 +1281,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetInnerClass() throws ClassNotFoundException {
+    void testGetInnerClass() throws ClassNotFoundException {
         assertEquals(Inner.DeeplyNested.class, ClassUtils.getClass("org.apache.commons.lang3.ClassUtilsTest.Inner.DeeplyNested"));
         assertEquals(Inner.DeeplyNested.class, ClassUtils.getClass("org.apache.commons.lang3.ClassUtilsTest.Inner$DeeplyNested"));
         assertEquals(Inner.DeeplyNested.class, ClassUtils.getClass("org.apache.commons.lang3.ClassUtilsTest$Inner$DeeplyNested"));
@@ -1288,7 +1301,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetPublicMethod() throws Exception {
+    void testGetPublicMethod() throws Exception {
         // Tests with Collections$UnmodifiableSet
         final Set<?> set = Collections.unmodifiableSet(new HashSet<>());
         final Method isEmptyMethod = ClassUtils.getPublicMethod(set.getClass(), "isEmpty");
@@ -1301,7 +1314,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testHierarchyExcludingInterfaces() {
+    void testHierarchyExcludingInterfaces() {
         final Iterator<Class<?>> iter = ClassUtils.hierarchy(StringParameterizedChild.class).iterator();
         assertEquals(StringParameterizedChild.class, iter.next());
         assertEquals(GenericParent.class, iter.next());
@@ -1310,7 +1323,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testHierarchyIncludingInterfaces() {
+    void testHierarchyIncludingInterfaces() {
         final Iterator<Class<?>> iter = ClassUtils.hierarchy(StringParameterizedChild.class, Interfaces.INCLUDE).iterator();
         assertEquals(StringParameterizedChild.class, iter.next());
         assertEquals(GenericParent.class, iter.next());
@@ -1320,7 +1333,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIsPrimitiveOrWrapper() {
+    void testIsPrimitiveOrWrapper() {
 
         // test primitive wrapper classes
         assertTrue(ClassUtils.isPrimitiveOrWrapper(Boolean.class), "Boolean.class");
@@ -1351,7 +1364,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIsPrimitiveWrapper() {
+    void testIsPrimitiveWrapper() {
 
         // test primitive wrapper classes
         assertTrue(ClassUtils.isPrimitiveWrapper(Boolean.class), "Boolean.class");
@@ -1382,7 +1395,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testPrimitivesToWrappers() {
+    void testPrimitivesToWrappers() {
         // test null
 //        assertNull("null -> null", ClassUtils.primitivesToWrappers(null)); // generates warning
         assertNull(ClassUtils.primitivesToWrappers((Class<?>[]) null), "null -> null"); // equivalent cast to avoid warning
@@ -1413,7 +1426,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testPrimitiveToWrapper() {
+    void testPrimitiveToWrapper() {
 
         // test primitive classes
         assertEquals(Boolean.class, ClassUtils.primitiveToWrapper(Boolean.TYPE), "boolean -> Boolean.class");
@@ -1437,7 +1450,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     // Show the Java bug: https://bugs.java.com/bugdatabase/view_bug.do?bug_id=4071957
     // We may have to delete this if a JDK fixes the bug.
     @Test
-    public void testShowJavaBug() throws Exception {
+    void testShowJavaBug() throws Exception {
         // Tests with Collections$UnmodifiableSet
         final Set<?> set = Collections.unmodifiableSet(new HashSet<>());
         final Method isEmptyMethod = set.getClass().getMethod("isEmpty");
@@ -1445,7 +1458,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testToClass_object() {
+    void testToClass_object() {
 //        assertNull(ClassUtils.toClass(null)); // generates warning
         assertNull(ClassUtils.toClass((Object[]) null)); // equivalent explicit cast
 
@@ -1462,7 +1475,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testWithInterleavingWhitespace() throws ClassNotFoundException {
+    void testWithInterleavingWhitespace() throws ClassNotFoundException {
         assertEquals(int[].class, ClassUtils.getClass(" int [ ] "));
         assertEquals(long[].class, ClassUtils.getClass("\rlong\t[\n]\r"));
         assertEquals(short[].class, ClassUtils.getClass("\tshort                \t\t[]"));
@@ -1470,7 +1483,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testWrappersToPrimitives() {
+    void testWrappersToPrimitives() {
         // an array with classes to test
         final Class<?>[] classes = {Boolean.class, Byte.class, Character.class, Short.class, Integer.class, Long.class, Float.class, Double.class, String.class,
             ClassUtils.class, null};
@@ -1485,13 +1498,13 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testWrappersToPrimitivesEmpty() {
+    void testWrappersToPrimitivesEmpty() {
         final Class<?>[] empty = new Class[0];
         assertArrayEquals(empty, ClassUtils.wrappersToPrimitives(empty), "Wrong result for empty input");
     }
 
     @Test
-    public void testWrappersToPrimitivesNull() {
+    void testWrappersToPrimitivesNull() {
 //        assertNull("Wrong result for null input", ClassUtils.wrappersToPrimitives(null)); // generates warning
         assertNull(ClassUtils.wrappersToPrimitives((Class<?>[]) null), "Wrong result for null input"); // equivalent cast
         // Other possible casts for null
@@ -1501,7 +1514,7 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testWrapperToPrimitive() {
+    void testWrapperToPrimitive() {
         // an array with classes to convert
         final Class<?>[] primitives = {Boolean.TYPE, Byte.TYPE, Character.TYPE, Short.TYPE, Integer.TYPE, Long.TYPE, Float.TYPE, Double.TYPE};
         for (final Class<?> primitive : primitives) {
@@ -1512,12 +1525,12 @@ public class ClassUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testWrapperToPrimitiveNoWrapper() {
+    void testWrapperToPrimitiveNoWrapper() {
         assertNull(ClassUtils.wrapperToPrimitive(String.class), "Wrong result for non wrapper class");
     }
 
     @Test
-    public void testWrapperToPrimitiveNull() {
+    void testWrapperToPrimitiveNull() {
         assertNull(ClassUtils.wrapperToPrimitive(null), "Wrong result for null class");
     }
 }
