@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -37,7 +37,7 @@ import org.junit.jupiter.api.Test;
  * Unit test for Tokenizer.
  */
 @Deprecated
-public class StrTokenizerTest extends AbstractLangTest {
+class StrTokenizerTest extends AbstractLangTest {
 
     private static final String CSV_SIMPLE_FIXTURE = "A,b,c";
 
@@ -49,7 +49,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test1() {
+    void test1() {
 
         final String input = "a;b;c;\"d;\"\"e\";f; ; ;  ";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -70,7 +70,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test2() {
+    void test2() {
 
         final String input = "a;b;c ;\"d;\"\"e\";f; ; ;";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -91,7 +91,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test3() {
+    void test3() {
 
         final String input = "a;b; c;\"d;\"\"e\";f; ; ;";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -112,7 +112,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test4() {
+    void test4() {
 
         final String input = "a;b; c;\"d;\"\"e\";f; ; ;";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -133,7 +133,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test5() {
+    void test5() {
 
         final String input = "a;b; c;\"d;\"\"e\";f; ; ;";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -155,7 +155,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test6() {
+    void test6() {
 
         final String input = "a;b; c;\"d;\"\"e\";f; ; ;";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -189,7 +189,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test7() {
+    void test7() {
 
         final String input = "a   b c \"d e\" f ";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -210,7 +210,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void test8() {
+    void test8() {
 
         final String input = "a   b c \"d e\" f ";
         final StrTokenizer tok = new StrTokenizer(input);
@@ -231,7 +231,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasic1() {
+    void testBasic1() {
         final String input = "a  b c";
         final StrTokenizer tok = new StrTokenizer(input);
         assertEquals("a", tok.next());
@@ -241,7 +241,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasic2() {
+    void testBasic2() {
         final String input = "a \nb\fc";
         final StrTokenizer tok = new StrTokenizer(input);
         assertEquals("a", tok.next());
@@ -251,7 +251,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasic3() {
+    void testBasic3() {
         final String input = "a \nb\u0001\fc";
         final StrTokenizer tok = new StrTokenizer(input);
         assertEquals("a", tok.next());
@@ -261,7 +261,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasic4() {
+    void testBasic4() {
         final String input = "a \"b\" c";
         final StrTokenizer tok = new StrTokenizer(input);
         assertEquals("a", tok.next());
@@ -271,7 +271,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasic5() {
+    void testBasic5() {
         final String input = "a:b':c";
         final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
         assertEquals("a", tok.next());
@@ -281,7 +281,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicDelim1() {
+    void testBasicDelim1() {
         final String input = "a:b:c";
         final StrTokenizer tok = new StrTokenizer(input, ':');
         assertEquals("a", tok.next());
@@ -291,7 +291,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicDelim2() {
+    void testBasicDelim2() {
         final String input = "a:b:c";
         final StrTokenizer tok = new StrTokenizer(input, ',');
         assertEquals("a:b:c", tok.next());
@@ -299,7 +299,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicEmpty1() {
+    void testBasicEmpty1() {
         final String input = "a  b c";
         final StrTokenizer tok = new StrTokenizer(input);
         tok.setIgnoreEmptyTokens(false);
@@ -311,7 +311,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicEmpty2() {
+    void testBasicEmpty2() {
         final String input = "a  b c";
         final StrTokenizer tok = new StrTokenizer(input);
         tok.setIgnoreEmptyTokens(false);
@@ -324,126 +324,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicQuoted1() {
-        final String input = "a 'b' c";
-        final StrTokenizer tok = new StrTokenizer(input, ' ', '\'');
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertEquals("c", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted2() {
-        final String input = "a:'b':";
-        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertNull(tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted3() {
-        final String input = "a:'b''c'";
-        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b'c", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted4() {
-        final String input = "a: 'b' 'c' :d";
-        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
-        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b c", tok.next());
-        assertEquals("d", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted5() {
-        final String input = "a: 'b'x'c' :d";
-        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
-        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("bxc", tok.next());
-        assertEquals("d", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted6() {
-        final String input = "a:'b'\"c':d";
-        final StrTokenizer tok = new StrTokenizer(input, ':');
-        tok.setQuoteMatcher(StrMatcher.quoteMatcher());
-        assertEquals("a", tok.next());
-        assertEquals("b\"c:d", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuoted7() {
-        final String input = "a:\"There's a reason here\":b";
-        final StrTokenizer tok = new StrTokenizer(input, ':');
-        tok.setQuoteMatcher(StrMatcher.quoteMatcher());
-        assertEquals("a", tok.next());
-        assertEquals("There's a reason here", tok.next());
-        assertEquals("b", tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicQuotedTrimmed1() {
-        final String input = "a: 'b' :";
-        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
-        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertNull(tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicTrimmed1() {
-        final String input = "a: b :  ";
-        final StrTokenizer tok = new StrTokenizer(input, ':');
-        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertNull(tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicTrimmed2() {
-        final String input = "a:  b  :";
-        final StrTokenizer tok = new StrTokenizer(input, ':');
-        tok.setTrimmerMatcher(StrMatcher.stringMatcher("  "));
-        tok.setIgnoreEmptyTokens(false);
-        tok.setEmptyTokenAsNull(true);
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertNull(tok.next());
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testBasicIgnoreTrimmed1() {
+    void testBasicIgnoreTrimmed1() {
         final String input = "a: bIGNOREc : ";
         final StrTokenizer tok = new StrTokenizer(input, ':');
         tok.setIgnoredMatcher(StrMatcher.stringMatcher("IGNORE"));
@@ -457,7 +338,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicIgnoreTrimmed2() {
+    void testBasicIgnoreTrimmed2() {
         final String input = "IGNOREaIGNORE: IGNORE bIGNOREc IGNORE : IGNORE ";
         final StrTokenizer tok = new StrTokenizer(input, ':');
         tok.setIgnoredMatcher(StrMatcher.stringMatcher("IGNORE"));
@@ -471,7 +352,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicIgnoreTrimmed3() {
+    void testBasicIgnoreTrimmed3() {
         final String input = "IGNOREaIGNORE: IGNORE bIGNOREc IGNORE : IGNORE ";
         final StrTokenizer tok = new StrTokenizer(input, ':');
         tok.setIgnoredMatcher(StrMatcher.stringMatcher("IGNORE"));
@@ -484,7 +365,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testBasicIgnoreTrimmed4() {
+    void testBasicIgnoreTrimmed4() {
         final String input = "IGNOREaIGNORE: IGNORE 'bIGNOREc'IGNORE'd' IGNORE : IGNORE ";
         final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
         tok.setIgnoredMatcher(StrMatcher.stringMatcher("IGNORE"));
@@ -498,63 +379,126 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testListArray() {
-        final String input = "a  b c";
-        final StrTokenizer tok = new StrTokenizer(input);
-        final String[] array = tok.getTokenArray();
-        final List<?> list = tok.getTokenList();
-
-        assertEquals(Arrays.asList(array), list);
-        assertEquals(3, list.size());
-    }
-
-    private void testCSV(final String data) {
-        this.testXSVAbc(StrTokenizer.getCSVInstance(data));
-        this.testXSVAbc(StrTokenizer.getCSVInstance(data.toCharArray()));
+    void testBasicQuoted1() {
+        final String input = "a 'b' c";
+        final StrTokenizer tok = new StrTokenizer(input, ' ', '\'');
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertEquals("c", tok.next());
+        assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testCSVEmpty() {
-        this.testEmpty(StrTokenizer.getCSVInstance());
-        this.testEmpty(StrTokenizer.getCSVInstance(""));
+    void testBasicQuoted2() {
+        final String input = "a:'b':";
+        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertNull(tok.next());
+        assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testCSVSimple() {
-        this.testCSV(CSV_SIMPLE_FIXTURE);
+    void testBasicQuoted3() {
+        final String input = "a:'b''c'";
+        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b'c", tok.next());
+        assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testCSVSimpleNeedsTrim() {
-        this.testCSV("   " + CSV_SIMPLE_FIXTURE);
-        this.testCSV("   \n\t  " + CSV_SIMPLE_FIXTURE);
-        this.testCSV("   \n  " + CSV_SIMPLE_FIXTURE + "\n\n\r");
-    }
-
-    void testEmpty(final StrTokenizer tokenizer) {
-        this.checkClone(tokenizer);
-        assertFalse(tokenizer.hasNext());
-        assertFalse(tokenizer.hasPrevious());
-        assertNull(tokenizer.nextToken());
-        assertEquals(0, tokenizer.size());
-        assertThrows(NoSuchElementException.class, tokenizer::next);
+    void testBasicQuoted4() {
+        final String input = "a: 'b' 'c' :d";
+        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
+        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b c", tok.next());
+        assertEquals("d", tok.next());
+        assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testGetContent() {
-        final String input = "a   b c \"d e\" f ";
-        StrTokenizer tok = new StrTokenizer(input);
-        assertEquals(input, tok.getContent());
-
-        tok = new StrTokenizer(input.toCharArray());
-        assertEquals(input, tok.getContent());
-
-        tok = new StrTokenizer();
-        assertNull(tok.getContent());
+    void testBasicQuoted5() {
+        final String input = "a: 'b'x'c' :d";
+        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
+        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("bxc", tok.next());
+        assertEquals("d", tok.next());
+        assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testChaining() {
+    void testBasicQuoted6() {
+        final String input = "a:'b'\"c':d";
+        final StrTokenizer tok = new StrTokenizer(input, ':');
+        tok.setQuoteMatcher(StrMatcher.quoteMatcher());
+        assertEquals("a", tok.next());
+        assertEquals("b\"c:d", tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testBasicQuoted7() {
+        final String input = "a:\"There's a reason here\":b";
+        final StrTokenizer tok = new StrTokenizer(input, ':');
+        tok.setQuoteMatcher(StrMatcher.quoteMatcher());
+        assertEquals("a", tok.next());
+        assertEquals("There's a reason here", tok.next());
+        assertEquals("b", tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testBasicQuotedTrimmed1() {
+        final String input = "a: 'b' :";
+        final StrTokenizer tok = new StrTokenizer(input, ':', '\'');
+        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertNull(tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testBasicTrimmed1() {
+        final String input = "a: b :  ";
+        final StrTokenizer tok = new StrTokenizer(input, ':');
+        tok.setTrimmerMatcher(StrMatcher.trimMatcher());
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertNull(tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testBasicTrimmed2() {
+        final String input = "a:  b  :";
+        final StrTokenizer tok = new StrTokenizer(input, ':');
+        tok.setTrimmerMatcher(StrMatcher.stringMatcher("  "));
+        tok.setIgnoreEmptyTokens(false);
+        tok.setEmptyTokenAsNull(true);
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertNull(tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testChaining() {
         final StrTokenizer tok = new StrTokenizer();
         assertEquals(tok, tok.reset());
         assertEquals(tok, tok.reset(""));
@@ -576,7 +520,7 @@ public class StrTokenizerTest extends AbstractLangTest {
      * {@code null}.
      */
     @Test
-    public void testCloneNotSupportedException() {
+    void testCloneNotSupportedException() {
         final Object notCloned = new StrTokenizer() {
             @Override
             Object cloneReset() throws CloneNotSupportedException {
@@ -587,7 +531,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testCloneNull() {
+    void testCloneNull() {
         final StrTokenizer tokenizer = new StrTokenizer((char[]) null);
         // Start sanity check
         assertNull(tokenizer.nextToken());
@@ -601,7 +545,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testCloneReset() {
+    void testCloneReset() {
         final char[] input = {'a'};
         final StrTokenizer tokenizer = new StrTokenizer(input);
         // Start sanity check
@@ -617,52 +561,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testConstructor_String() {
-        StrTokenizer tok = new StrTokenizer("a b");
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer("");
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer((String) null);
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testConstructor_String_char() {
-        StrTokenizer tok = new StrTokenizer("a b", ' ');
-        assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer("", ' ');
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer((String) null, ' ');
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testConstructor_String_char_char() {
-        StrTokenizer tok = new StrTokenizer("a b", ' ', '"');
-        assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
-        assertEquals(1, tok.getQuoteMatcher().isMatch("\"".toCharArray(), 0, 0, 1));
-        assertEquals("a", tok.next());
-        assertEquals("b", tok.next());
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer("", ' ', '"');
-        assertFalse(tok.hasNext());
-
-        tok = new StrTokenizer((String) null, ' ', '"');
-        assertFalse(tok.hasNext());
-    }
-
-    @Test
-    public void testConstructor_charArray() {
+    void testConstructor_charArray() {
         StrTokenizer tok = new StrTokenizer("a b".toCharArray());
         assertEquals("a", tok.next());
         assertEquals("b", tok.next());
@@ -676,7 +575,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testConstructor_charArray_char() {
+    void testConstructor_charArray_char() {
         StrTokenizer tok = new StrTokenizer("a b".toCharArray(), ' ');
         assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
         assertEquals("a", tok.next());
@@ -691,7 +590,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testConstructor_charArray_char_char() {
+    void testConstructor_charArray_char_char() {
         StrTokenizer tok = new StrTokenizer("a b".toCharArray(), ' ', '"');
         assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
         assertEquals(1, tok.getQuoteMatcher().isMatch("\"".toCharArray(), 0, 0, 1));
@@ -707,84 +606,97 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testReset() {
-        final StrTokenizer tok = new StrTokenizer("a b c");
+    void testConstructor_String() {
+        StrTokenizer tok = new StrTokenizer("a b");
         assertEquals("a", tok.next());
         assertEquals("b", tok.next());
-        assertEquals("c", tok.next());
         assertFalse(tok.hasNext());
 
-        tok.reset();
+        tok = new StrTokenizer("");
+        assertFalse(tok.hasNext());
+
+        tok = new StrTokenizer((String) null);
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testConstructor_String_char() {
+        StrTokenizer tok = new StrTokenizer("a b", ' ');
+        assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
         assertEquals("a", tok.next());
         assertEquals("b", tok.next());
-        assertEquals("c", tok.next());
+        assertFalse(tok.hasNext());
+
+        tok = new StrTokenizer("", ' ');
+        assertFalse(tok.hasNext());
+
+        tok = new StrTokenizer((String) null, ' ');
         assertFalse(tok.hasNext());
     }
 
     @Test
-    public void testReset_String() {
-        final StrTokenizer tok = new StrTokenizer("x x x");
-        tok.reset("d e");
-        assertEquals("d", tok.next());
-        assertEquals("e", tok.next());
+    void testConstructor_String_char_char() {
+        StrTokenizer tok = new StrTokenizer("a b", ' ', '"');
+        assertEquals(1, tok.getDelimiterMatcher().isMatch(" ".toCharArray(), 0, 0, 1));
+        assertEquals(1, tok.getQuoteMatcher().isMatch("\"".toCharArray(), 0, 0, 1));
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
         assertFalse(tok.hasNext());
 
-        tok.reset((String) null);
+        tok = new StrTokenizer("", ' ', '"');
         assertFalse(tok.hasNext());
+
+        tok = new StrTokenizer((String) null, ' ', '"');
+        assertFalse(tok.hasNext());
+    }
+
+    private void testCSV(final String data) {
+        testXSVAbc(StrTokenizer.getCSVInstance(data));
+        testXSVAbc(StrTokenizer.getCSVInstance(data.toCharArray()));
     }
 
     @Test
-    public void testReset_charArray() {
-        final StrTokenizer tok = new StrTokenizer("x x x");
-
-        final char[] array = {'a', 'b', 'c'};
-        tok.reset(array);
-        assertEquals("abc", tok.next());
-        assertFalse(tok.hasNext());
-
-        tok.reset((char[]) null);
-        assertFalse(tok.hasNext());
+    void testCSVEmpty() {
+        testEmpty(StrTokenizer.getCSVInstance());
+        testEmpty(StrTokenizer.getCSVInstance(""));
     }
 
     @Test
-    public void testTSV() {
-        this.testXSVAbc(StrTokenizer.getTSVInstance(TSV_SIMPLE_FIXTURE));
-        this.testXSVAbc(StrTokenizer.getTSVInstance(TSV_SIMPLE_FIXTURE.toCharArray()));
+    void testCSVSimple() {
+        testCSV(CSV_SIMPLE_FIXTURE);
     }
 
     @Test
-    public void testTSVEmpty() {
-        this.testEmpty(StrTokenizer.getTSVInstance());
-        this.testEmpty(StrTokenizer.getTSVInstance(""));
+    void testCSVSimpleNeedsTrim() {
+        testCSV("   " + CSV_SIMPLE_FIXTURE);
+        testCSV("   \n\t  " + CSV_SIMPLE_FIXTURE);
+        testCSV("   \n  " + CSV_SIMPLE_FIXTURE + "\n\n\r");
     }
 
-    void testXSVAbc(final StrTokenizer tokenizer) {
-        this.checkClone(tokenizer);
-        assertEquals(-1, tokenizer.previousIndex());
-        assertEquals(0, tokenizer.nextIndex());
-        assertNull(tokenizer.previousToken());
-        assertEquals("A", tokenizer.nextToken());
-        assertEquals(1, tokenizer.nextIndex());
-        assertEquals("b", tokenizer.nextToken());
-        assertEquals(2, tokenizer.nextIndex());
-        assertEquals("c", tokenizer.nextToken());
-        assertEquals(3, tokenizer.nextIndex());
+    void testEmpty(final StrTokenizer tokenizer) {
+        checkClone(tokenizer);
+        assertFalse(tokenizer.hasNext());
+        assertFalse(tokenizer.hasPrevious());
         assertNull(tokenizer.nextToken());
-        assertEquals(3, tokenizer.nextIndex());
-        assertEquals("c", tokenizer.previousToken());
-        assertEquals(2, tokenizer.nextIndex());
-        assertEquals("b", tokenizer.previousToken());
-        assertEquals(1, tokenizer.nextIndex());
-        assertEquals("A", tokenizer.previousToken());
-        assertEquals(0, tokenizer.nextIndex());
-        assertNull(tokenizer.previousToken());
-        assertEquals(0, tokenizer.nextIndex());
-        assertEquals(-1, tokenizer.previousIndex());
-        assertEquals(3, tokenizer.size());
+        assertEquals(0, tokenizer.size());
+        assertThrows(NoSuchElementException.class, tokenizer::next);
     }
 
     @Test
-    public void testIteration() {
+    void testGetContent() {
+        final String input = "a   b c \"d e\" f ";
+        StrTokenizer tok = new StrTokenizer(input);
+        assertEquals(input, tok.getContent());
+
+        tok = new StrTokenizer(input.toCharArray());
+        assertEquals(input, tok.getContent());
+
+        tok = new StrTokenizer();
+        assertNull(tok.getContent());
+    }
+
+    @Test
+    void testIteration() {
         final StrTokenizer tkn = new StrTokenizer("a b c");
         assertFalse(tkn.hasPrevious());
         assertThrows(NoSuchElementException.class, tkn::previous);
@@ -811,7 +723,58 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testTokenizeSubclassInputChange() {
+    void testListArray() {
+        final String input = "a  b c";
+        final StrTokenizer tok = new StrTokenizer(input);
+        final String[] array = tok.getTokenArray();
+        final List<?> list = tok.getTokenList();
+
+        assertEquals(Arrays.asList(array), list);
+        assertEquals(3, list.size());
+    }
+
+    @Test
+    void testReset() {
+        final StrTokenizer tok = new StrTokenizer("a b c");
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertEquals("c", tok.next());
+        assertFalse(tok.hasNext());
+
+        tok.reset();
+        assertEquals("a", tok.next());
+        assertEquals("b", tok.next());
+        assertEquals("c", tok.next());
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testReset_charArray() {
+        final StrTokenizer tok = new StrTokenizer("x x x");
+
+        final char[] array = {'a', 'b', 'c'};
+        tok.reset(array);
+        assertEquals("abc", tok.next());
+        assertFalse(tok.hasNext());
+
+        tok.reset((char[]) null);
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testReset_String() {
+        final StrTokenizer tok = new StrTokenizer("x x x");
+        tok.reset("d e");
+        assertEquals("d", tok.next());
+        assertEquals("e", tok.next());
+        assertFalse(tok.hasNext());
+
+        tok.reset((String) null);
+        assertFalse(tok.hasNext());
+    }
+
+    @Test
+    void testTokenizeSubclassInputChange() {
         final StrTokenizer tkn = new StrTokenizer("a b c d e") {
             @Override
             protected List<String> tokenize(final char[] chars, final int offset, final int count) {
@@ -823,7 +786,7 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testTokenizeSubclassOutputChange() {
+    void testTokenizeSubclassOutputChange() {
         final StrTokenizer tkn = new StrTokenizer("a b c") {
             @Override
             protected List<String> tokenize(final char[] chars, final int offset, final int count) {
@@ -838,11 +801,48 @@ public class StrTokenizerTest extends AbstractLangTest {
     }
 
     @Test
-    public void testToString() {
+    void testToString() {
         final StrTokenizer tkn = new StrTokenizer("a b c d e");
         assertEquals("StrTokenizer[not tokenized yet]", tkn.toString());
         tkn.next();
         assertEquals("StrTokenizer[a, b, c, d, e]", tkn.toString());
     }
 
+    @Test
+    void testTSV() {
+        testXSVAbc(StrTokenizer.getTSVInstance(TSV_SIMPLE_FIXTURE));
+        testXSVAbc(StrTokenizer.getTSVInstance(TSV_SIMPLE_FIXTURE.toCharArray()));
+    }
+
+    @Test
+    void testTSVEmpty() {
+        testEmpty(StrTokenizer.getTSVInstance());
+        testEmpty(StrTokenizer.getTSVInstance(""));
+    }
+
+    void testXSVAbc(final StrTokenizer tokenizer) {
+        checkClone(tokenizer);
+        assertEquals(-1, tokenizer.previousIndex());
+        assertEquals(0, tokenizer.nextIndex());
+        assertNull(tokenizer.previousToken());
+        assertEquals("A", tokenizer.nextToken());
+        assertEquals(1, tokenizer.nextIndex());
+        assertEquals("b", tokenizer.nextToken());
+        assertEquals(2, tokenizer.nextIndex());
+        assertEquals("c", tokenizer.nextToken());
+        assertEquals(3, tokenizer.nextIndex());
+        assertNull(tokenizer.nextToken());
+        assertEquals(3, tokenizer.nextIndex());
+        assertEquals("c", tokenizer.previousToken());
+        assertEquals(2, tokenizer.nextIndex());
+        assertEquals("b", tokenizer.previousToken());
+        assertEquals(1, tokenizer.nextIndex());
+        assertEquals("A", tokenizer.previousToken());
+        assertEquals(0, tokenizer.nextIndex());
+        assertNull(tokenizer.previousToken());
+        assertEquals(0, tokenizer.nextIndex());
+        assertEquals(-1, tokenizer.previousIndex());
+        assertEquals(3, tokenizer.size());
+    }
+
 }
